/*-
 * Copyright 2016 Vsevolod Stakhov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef SRC_LIBCRYPTOBOX_BASE64_BASE64_H_
#define SRC_LIBCRYPTOBOX_BASE64_BASE64_H_

#include "config.h"

#ifdef __cplusplus
extern "C" {
#endif

const char *base64_load(void);

#ifdef __cplusplus
}
#endif

#endif /* SRC_LIBCRYPTOBOX_BASE64_BASE64_H_ */
